@@ -1,6 +1,6 @@
 package Resque;
 # ABSTRACT: Redis-backed library for creating background jobs, placing them on multiple queues, and processing them later.
-$Resque::VERSION = '0.28';
+$Resque::VERSION = '0.29';
 use Moose;
 use Scalar::Util 'blessed';
 use Moose::Util::TypeConstraints;
@@ -94,6 +94,11 @@ sub remove_queue {
     $self->redis->del( $self->key( queue => $queue ) );
 }
 
+sub create_queue {
+    my ( $self, $queue ) = @_;
+    $self->_watch_queue( $queue );
+}
+
 sub mass_dequeue {
     my ( $self, $target ) = @_;
     confess("Can't mass_dequeue() without queue and class names.")
@@ -176,7 +181,7 @@ Resque - Redis-backed library for creating background jobs, placing them on mult
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 SYNOPSIS
 
@@ -263,6 +268,8 @@ Failures handler. See L<Resque::Failures>.
 Returns a new L<Resque::Worker> on this resque instance.
 It can have plugin/roles applied. See L<Resque::Pluggable>.
 
+    my $worker = $r->worker();
+
 =head2 push
 
 Pushes a job onto a queue. Queue name should be a string and the
@@ -283,14 +290,18 @@ Pops a job off a queue. Queue name should be a string.
 
 Returns a Resque::Job object.
 
+    my $resque_job = $r->pop( 'queue_name' );
+
 =head2 size
 
 Returns the size of a queue.
 Queue name should be a string.
 
+    my $size = $r->size();
+
 =head2 peek
 
-Returns an array of jobs currently queued.
+Returns an array of jobs currently queued, or an arrayref in scalar context.
 
 First argument is queue name and an optional secound and third are
 start and count values that can be used for pagination.
@@ -301,16 +312,27 @@ of count. So, passing -1 will return full list, -2 all but last
 element and so on.
 
 To get the 3rd page of a 30 item, paginatied list one would use:
-    $resque->peek('my_queue', 59, 30)
+
+    my @jobs = $resque->peek('my_queue', 59, 30)
 
 =head2 queues
 
-Returns an array of all known Resque queues.
+Returns an array of all known Resque queues, or an arrayref in scalar context.
+
+    my @queues = $r->queues();
 
 =head2 remove_queue
 
 Given a queue name, completely deletes the queue.
 
+    $r->remove_queue( 'my_queue' );
+
+=head2 create_queue
+
+Given a queue name, creates an empty queue.
+
+    $r-create_queue( 'my_queue' );
+
 =head2 mass_dequeue
 
 Removes all matching jobs from a queue. Expects a hashref
@@ -328,14 +350,14 @@ That is, for these two jobs:
 
 The following call will remove both:
 
-    $rescue->mass_dequeue({
+    my $num_removed = $rescue->mass_dequeue({
         queue => 'test',
         class => 'UpdateGraph'
     });
 
 Whereas specifying args will only remove the 2nd job:
 
-    $rescue->mass_dequeue({
+    my $num_removed = $rescue->mass_dequeue({
         queue => 'test',
         class => 'UpdateGraph',
         args  => ['ruby']
@@ -353,6 +375,8 @@ hashref or string(payload for object).
 L<Resque::Job> class can be extended thru roles/plugins.
 See L<Resque::Pluggable>.
 
+    $r->new_job( $job_or_job_hashref );
+
 =head2 key
 
 Concatenate $self->namespace with the received array of names
@@ -360,18 +384,23 @@ to build a redis key name for this resque instance.
 
 =head2 keys
 
-Returns an array of all known Resque keys in Redis. Redis' KEYS operation
-is O(N) for the keyspace, so be careful - this can be slow for big databases.
+Returns an array of all known Resque keys in Redis, or an arrayref in scalar context. 
+Redis' KEYS operation is O(N) for the keyspace, so be careful - 
+this can be slow for big databases.
 
 =head2 flush_namespace
 
 This method will delete every trace of this Resque system on
 the redis() backend.
 
+    $r->flush_namespace();
+
 =head2 list_range
 
 Does the dirty work of fetching a range of items from a Redis list.
 
+    my $items_ref = $r->list_range( $key, $stat, $count );
+
 =head1 Queue manipulation
 
 =head1 HELPER METHODS
