@@ -1,6 +1,6 @@
 package Resque::Job;
 # ABSTRACT: Resque job container
-$Resque::Job::VERSION = '0.28';
+$Resque::Job::VERSION = '0.29';
 use Moose;
 use Moose::Util::TypeConstraints;
 with 'Resque::Encoder';
@@ -127,12 +127,14 @@ Resque::Job - Resque job container
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 ATTRIBUTES
 
 =head2 resque
 
+Provides 'redis' method, which provides access to our redis subsystem.
+
 =head2 worker
 
 Worker running this job.
@@ -163,12 +165,22 @@ This is read-only.
 
 String representation(JSON) to be used on the backend.
 
+    $job->encode();
+
 =head2 stringify
 
+Returns a string version of the job, like
+
+'(Job{queue_name) | ClassName | args_encoded)'
+
+    my $stringified = $job->stringify();
+
 =head2 queue_from_class
 
 Normalize class name to be used as queue name.
 
+    my $queue_name = $job->queue_from_class();
+
     NOTE: future versions will try to get the
           queue name from the real class attr
           or $class::queue global variable.
@@ -178,11 +190,15 @@ Normalize class name to be used as queue name.
 Load job class and call perform() on it.
 This job object will be passed as the only argument.
 
+    $job->perform();
+
 =head2 enqueue
 
 Add this job to resque.
 See Rescue::push().
 
+    $job->enqueue();
+
 =head2 dequeue
 
 Remove this job from resque using the most restrictive
@@ -192,9 +208,14 @@ object queue, class and args.
 
 See Resque::mass_dequeue() for massive destruction.
 
+    $job->enqueue();
+
 =head2 fail
 
-Store a failure on this job.
+Store a failure (or arrayref of failures) on this job.
+
+    $job->fail( "error message'); # or
+    $job->fail( ['msg1', 'msg2'] );
 
 =head1 AUTHOR
 
