@@ -1,6 +1,6 @@
 package Resque::Worker;
 # ABSTRACT: Does the hard work of babysitting Resque::Job's
-$Resque::Worker::VERSION = '0.28';
+$Resque::Worker::VERSION = '0.29';
 use Moose;
 with 'Resque::Encoder';
 
@@ -404,7 +404,7 @@ Resque::Worker - Does the hard work of babysitting Resque::Job's
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 ATTRIBUTES
 
@@ -463,97 +463,139 @@ Float representing the polling frequency. The default is 5 seconds, but for a se
 Stop processing jobs after the current one has completed (if we're
 currently running one).
 
+$worker->pause();
+
 =head2 unpause
 
 Start processing jobs again after a pause
 
+$worker->unpause();
+
 =head2 shutdown_please
 
 Schedule this worker for shutdown. Will finish processing the
 current job.
 
+$worker->shutdown_please();
+
 =head2 shutdown_now
 
 Kill the child and shutdown immediately.
 
+$worker->shutdown_now();
+
 =head2 work
 
-Calling this method will make this worker to start pulling & running jobs
+Calling this method will make this worker start pulling & running jobs
 from queues().
 
 This is the main wheel and will run while shutdown() is false.
 
+$worker->work();
+
 =head2 work_tick
 
 Perform() one job and wait till it finish.
 
+$worker->work_tick();
+
 =head2 perform
 
 Call perform() on the given Resque::Job capturing and reporting
 any exception.
 
+$worker->perform( $job );
+
 =head2 kill_child
 
 Kills the forked child immediately, without remorse. The job it
 is processing will not be completed.
 
+$worker->kill_child();
+
 =head2 add_queue
 
 Add a queue this worker should listen to.
 
+$worker->add_queue( "queuename" );
+
 =head2 del_queue
 
 Stop listening to the given queue.
 
+$worker->del_queue( "queuename" );
+
 =head2 reserve
 
 Pull the next job to be precessed.
 
+my $job = $worker->reserve();
+
 =head2 working_on
 
 Set worker and working status on the given L<Resque::Job>.
 
+$job->working_on( $resque_job );
+
 =head2 done_working
 
 Inform the backend this worker has done its current job
 
+$job->done_working();
+
 =head2 started
 
 What time did this worker start?
 Returns an instance of DateTime.
 
+my $datetime = $worker->started();
+
 =head2 set_started
 
 Tell Redis we've started
 
+$worker->set_started();
+
 =head2 processing
 
 Returns a hash explaining the Job we're currently processing, if any.
 
+$worker->processing();
+
 =head2 processing_started
 
 What time did this worker started to work on current job?
 Returns an instance of DateTime or undef when it's not working.
 
+my $datetime = $worker->processing_started();
+
 =head2 state
 
 Returns a string representing the current worker state,
 which can be either working or idle
 
+my $state = $worker->state();
+
 =head2 is_working
 
 Boolean - true if working, false if not
 
+my $working = $worker->is_working();
+
 =head2 is_idle
 
 Boolean - true if idle, false if not
 
+my $idle = $worker->is_idle();
+
 =head2 procline
 
 Given a string, sets the procline ($0) and logs.
 Procline is always in the format of:
     resque-VERSION: STRING
 
+$worker->procline( "string" );
+
 =head2 startup
 
 Helper method called by work() to:
@@ -562,6 +604,8 @@ Helper method called by work() to:
   2. prune_dead_workers();
   3. register_worker();
 
+$worker->startup();
+
 =head2 register_signal_handlers
 
 Registers the various signal handlers a worker responds to.
@@ -573,6 +617,8 @@ Registers the various signal handlers a worker responds to.
  USR2: Don't process any new jobs
  CONT: Start processing jobs again after a USR2
 
+$worker->register_signal_handlers();
+
 =head2 prune_dead_workers
 
 Looks for any workers which should be running on this server
@@ -586,46 +632,67 @@ will leave stale state information in Redis.
 By checking the current Redis state against the actual
 environment, we can determine if Redis is old and clean it up a bit.
 
+$worker->prune_dead_worker();
+
 =head2 register_worker
 
 Registers ourself as a worker. Useful when entering the worker
 lifecycle on startup.
 
+$worker->register_worker();
+
 =head2 unregister_worker
 
 Unregisters ourself as a worker. Useful when shutting down.
 
+$worker->unregister_worker();
+
 =head2 worker_pids
 
 Returns an Array of string pids of all the other workers on this
 machine. Useful when pruning dead workers on startup.
 
+my @pids = $worker->worker_pids();
+
 =head2 log
 
 If verbose() is true, this will print to STDERR.
 
+$worker->log( 'message here' );
+
 =head2 processed
 
 Retrieve from L<Resque::Stat> many jobs has done this worker.
-Pass a true argument to increment by one.
+Pass a true argument to increment by one before retrieval.
+
+my $jobs_run = $worker->processed( $boolean );
 
 =head2 failed
 
 How many failed jobs has this worker seen.
-Pass a true argument to increment by one.
+Pass a true argument to increment by one before retrieval.
+
+my $jobs_run = $worker->processed( $boolean );
 
 =head2 find
 
 Returns a single worker object. Accepts a string id.
 
+my $worker_object = $worker->find( $worker_id );
+
 =head2 all
 
-Returns all worker registered on the backend.
+Returns a list of all worker registered on the backend, or an
+arrayref in scalar context;
+
+my @workers = $worker->all();
 
 =head2 exists
 
 Returns true if the given worker id exists on redis() backend.
 
+my $exists = $worker->exists( $worker_id );
+
 =head1 AUTHOR
 
 Diego Kuperman <diego@freekeylabs.com>
